@@ -53,5 +53,10 @@ model_get_contrasts_3 <- function(model) {
   )
 }
 
+#' @export
+#' @rdname model_get_contrasts
+model_get_contrasts.model_fit <- function(model) {
+  model_get_contrasts(model$fit)
+}
 
 
