@@ -21,12 +21,13 @@ tidy_remove_intercept <- function(x, model = tidy_get_model(x)) {
     stop("'model' is not provided. You need to pass it or to use 'tidy_and_attach()'.")
   }
 
+  .attributes <- .save_attributes(x)
+
   if (!"var_type" %in% names(x)) {
     x <- x %>% tidy_identify_variables(model = model)
   }
 
   x %>%
     dplyr::filter(.data$var_type != "intercept") %>%
-    tidy_attach_model(model = model) %>%
-    .order_tidy_columns()
+    tidy_attach_model(model = model, .attributes = .attributes)
 }
